#!/usr/bin/env bash
###############################################################################
#
# Bash Remediation Script for NIST National Checklist for Red Hat Enterprise Linux CoreOS
#
# Profile Description:
# This compliance profile reflects the core set of security
# related configuration settings for deployment of Red Hat Enterprise
# Linux CoreOS into U.S. Defense, Intelligence, and Civilian agencies.
# Development partners and sponsors include the U.S. National Institute
# of Standards and Technology (NIST), U.S. Department of Defense,
# the National Security Agency, and Red Hat.
# This baseline implements configuration requirements from the following
# sources:
# - Committee on National Security Systems Instruction No. 1253 (CNSSI 1253)
# - NIST Controlled Unclassified Information (NIST 800-171)
# - NIST 800-53 control selections for MODERATE impact systems (NIST 800-53)
# - U.S. Government Configuration Baseline (USGCB)
# - NIAP Protection Profile for General Purpose Operating Systems v4.2.1 (OSPP v4.2.1)
# - DISA Operating System Security Requirements Guide (OS SRG)
# For any differing configuration requirements, e.g. password lengths, the stricter
# security setting was chosen. Security Requirement Traceability Guides (RTMs) and
# sample System Security Configuration Guides are provided via the
# scap-security-guide-docs package.
# This profile reflects U.S. Government consensus content and is developed through
# the OpenSCAP/SCAP Security Guide initiative, championed by the National
# Security Agency. Except for differences in formatting to accommodate
# publishing processes, this profile mirrors OpenSCAP/SCAP Security Guide
# content as minor divergences, such as bugfixes, work through the
# consensus and release processes.
#
# Profile ID:  moderate
# Benchmark ID:  OCP-4
# Benchmark Version:  0.1.49
# XCCDF Version:  1.1
#
# This file was generated by OpenSCAP 1.3.6 using:
# $ oscap xccdf generate fix --profile moderate --fix-type bash xccdf-file.xml
#
# This Bash Remediation Script is generated from an OpenSCAP profile without preliminary evaluation.
# It attempts to fix every selected rule, even if the system is already compliant.
#
# How to apply this Bash Remediation Script:
# $ sudo ./remediation-script.sh
#
###############################################################################

###############################################################################
# BEGIN fix (1 / 244) for 'grub2_pti_argument'
###############################################################################
(>&2 echo "Remediating rule 1/244: 'grub2_pti_argument'")
(>&2 echo "FIX FOR THIS RULE 'grub2_pti_argument' IS MISSING!")

# END fix for 'grub2_pti_argument'

###############################################################################
# BEGIN fix (2 / 244) for 'grub2_uefi_password'
###############################################################################
(>&2 echo "Remediating rule 2/244: 'grub2_uefi_password'")
(>&2 echo "FIX FOR THIS RULE 'grub2_uefi_password' IS MISSING!")

# END fix for 'grub2_uefi_password'

###############################################################################
# BEGIN fix (3 / 244) for 'ensure_logrotate_activated'
###############################################################################
(>&2 echo "Remediating rule 3/244: 'ensure_logrotate_activated'")

LOGROTATE_CONF_FILE="/etc/logrotate.conf"
CRON_DAILY_LOGROTATE_FILE="/etc/cron.daily/logrotate"

# daily rotation is configured
grep -q "^daily$" $LOGROTATE_CONF_FILE|| echo "daily" >> $LOGROTATE_CONF_FILE

# remove any line configuring weekly, monthly or yearly rotation
sed -i -r "/^(weekly|monthly|yearly)$/d" $LOGROTATE_CONF_FILE

# configure cron.daily if not already
if ! grep -q "^[[:space:]]*/usr/sbin/logrotate[[:alnum:][:blank:][:punct:]]*$LOGROTATE_CONF_FILE$" $CRON_DAILY_LOGROTATE_FILE; then
	echo "#!/bin/sh" > $CRON_DAILY_LOGROTATE_FILE
	echo "/usr/sbin/logrotate $LOGROTATE_CONF_FILE" >> $CRON_DAILY_LOGROTATE_FILE
fi

# END fix for 'ensure_logrotate_activated'

###############################################################################
# BEGIN fix (4 / 244) for 'grub2_enable_selinux'
###############################################################################
(>&2 echo "Remediating rule 4/244: 'grub2_enable_selinux'")
(>&2 echo "FIX FOR THIS RULE 'grub2_enable_selinux' IS MISSING!")

# END fix for 'grub2_enable_selinux'

###############################################################################
# BEGIN fix (5 / 244) for 'selinux_policytype'
###############################################################################
(>&2 echo "Remediating rule 5/244: 'selinux_policytype'")
(>&2 echo "FIX FOR THIS RULE 'selinux_policytype' IS MISSING!")

# END fix for 'selinux_policytype'

###############################################################################
# BEGIN fix (6 / 244) for 'selinux_confinement_of_daemons'
###############################################################################
(>&2 echo "Remediating rule 6/244: 'selinux_confinement_of_daemons'")
(>&2 echo "FIX FOR THIS RULE 'selinux_confinement_of_daemons' IS MISSING!")

# END fix for 'selinux_confinement_of_daemons'

###############################################################################
# BEGIN fix (7 / 244) for 'selinux_state'
###############################################################################
(>&2 echo "Remediating rule 7/244: 'selinux_state'")
(>&2 echo "FIX FOR THIS RULE 'selinux_state' IS MISSING!")

# END fix for 'selinux_state'

###############################################################################
# BEGIN fix (8 / 244) for 'network_nmcli_permissions'
###############################################################################
(>&2 echo "Remediating rule 8/244: 'network_nmcli_permissions'")
(>&2 echo "FIX FOR THIS RULE 'network_nmcli_permissions' IS MISSING!")

# END fix for 'network_nmcli_permissions'

###############################################################################
# BEGIN fix (9 / 244) for 'wireless_disable_in_bios'
###############################################################################
(>&2 echo "Remediating rule 9/244: 'wireless_disable_in_bios'")
(>&2 echo "FIX FOR THIS RULE 'wireless_disable_in_bios' IS MISSING!")

# END fix for 'wireless_disable_in_bios'

###############################################################################
# BEGIN fix (10 / 244) for 'kernel_module_bluetooth_disabled'
###############################################################################
(>&2 echo "Remediating rule 10/244: 'kernel_module_bluetooth_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_bluetooth_disabled' IS MISSING!")

# END fix for 'kernel_module_bluetooth_disabled'

###############################################################################
# BEGIN fix (11 / 244) for 'wireless_disable_interfaces'
###############################################################################
(>&2 echo "Remediating rule 11/244: 'wireless_disable_interfaces'")
(>&2 echo "FIX FOR THIS RULE 'wireless_disable_interfaces' IS MISSING!")

# END fix for 'wireless_disable_interfaces'

###############################################################################
# BEGIN fix (12 / 244) for 'package_iptables_installed'
###############################################################################
(>&2 echo "Remediating rule 12/244: 'package_iptables_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_iptables_installed' IS MISSING!")

# END fix for 'package_iptables_installed'

###############################################################################
# BEGIN fix (13 / 244) for 'kernel_module_can_disabled'
###############################################################################
(>&2 echo "Remediating rule 13/244: 'kernel_module_can_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_can_disabled' IS MISSING!")

# END fix for 'kernel_module_can_disabled'

###############################################################################
# BEGIN fix (14 / 244) for 'kernel_module_atm_disabled'
###############################################################################
(>&2 echo "Remediating rule 14/244: 'kernel_module_atm_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_atm_disabled' IS MISSING!")

# END fix for 'kernel_module_atm_disabled'

###############################################################################
# BEGIN fix (15 / 244) for 'kernel_module_sctp_disabled'
###############################################################################
(>&2 echo "Remediating rule 15/244: 'kernel_module_sctp_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_sctp_disabled' IS MISSING!")

# END fix for 'kernel_module_sctp_disabled'

###############################################################################
# BEGIN fix (16 / 244) for 'kernel_module_firewire-core_disabled'
###############################################################################
(>&2 echo "Remediating rule 16/244: 'kernel_module_firewire-core_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_firewire-core_disabled' IS MISSING!")

# END fix for 'kernel_module_firewire-core_disabled'

###############################################################################
# BEGIN fix (17 / 244) for 'kernel_module_tipc_disabled'
###############################################################################
(>&2 echo "Remediating rule 17/244: 'kernel_module_tipc_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_tipc_disabled' IS MISSING!")

# END fix for 'kernel_module_tipc_disabled'

###############################################################################
# BEGIN fix (18 / 244) for 'sysctl_net_ipv4_conf_all_accept_redirects'
###############################################################################
(>&2 echo "Remediating rule 18/244: 'sysctl_net_ipv4_conf_all_accept_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_all_accept_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_all_accept_redirects'

###############################################################################
# BEGIN fix (19 / 244) for 'sysctl_net_ipv4_conf_default_secure_redirects'
###############################################################################
(>&2 echo "Remediating rule 19/244: 'sysctl_net_ipv4_conf_default_secure_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_default_secure_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_default_secure_redirects'

###############################################################################
# BEGIN fix (20 / 244) for 'sysctl_net_ipv4_conf_default_log_martians'
###############################################################################
(>&2 echo "Remediating rule 20/244: 'sysctl_net_ipv4_conf_default_log_martians'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_default_log_martians' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_default_log_martians'

###############################################################################
# BEGIN fix (21 / 244) for 'sysctl_net_ipv4_conf_all_secure_redirects'
###############################################################################
(>&2 echo "Remediating rule 21/244: 'sysctl_net_ipv4_conf_all_secure_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_all_secure_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_all_secure_redirects'

###############################################################################
# BEGIN fix (22 / 244) for 'sysctl_net_ipv4_icmp_echo_ignore_broadcasts'
###############################################################################
(>&2 echo "Remediating rule 22/244: 'sysctl_net_ipv4_icmp_echo_ignore_broadcasts'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_icmp_echo_ignore_broadcasts' IS MISSING!")

# END fix for 'sysctl_net_ipv4_icmp_echo_ignore_broadcasts'

###############################################################################
# BEGIN fix (23 / 244) for 'sysctl_net_ipv4_conf_default_rp_filter'
###############################################################################
(>&2 echo "Remediating rule 23/244: 'sysctl_net_ipv4_conf_default_rp_filter'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_default_rp_filter' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_default_rp_filter'

###############################################################################
# BEGIN fix (24 / 244) for 'sysctl_net_ipv4_tcp_syncookies'
###############################################################################
(>&2 echo "Remediating rule 24/244: 'sysctl_net_ipv4_tcp_syncookies'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_tcp_syncookies' IS MISSING!")

# END fix for 'sysctl_net_ipv4_tcp_syncookies'

###############################################################################
# BEGIN fix (25 / 244) for 'sysctl_net_ipv4_conf_all_log_martians'
###############################################################################
(>&2 echo "Remediating rule 25/244: 'sysctl_net_ipv4_conf_all_log_martians'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_all_log_martians' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_all_log_martians'

###############################################################################
# BEGIN fix (26 / 244) for 'sysctl_net_ipv4_conf_all_accept_source_route'
###############################################################################
(>&2 echo "Remediating rule 26/244: 'sysctl_net_ipv4_conf_all_accept_source_route'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_all_accept_source_route' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_all_accept_source_route'

###############################################################################
# BEGIN fix (27 / 244) for 'sysctl_net_ipv4_conf_default_accept_source_route'
###############################################################################
(>&2 echo "Remediating rule 27/244: 'sysctl_net_ipv4_conf_default_accept_source_route'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_default_accept_source_route' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_default_accept_source_route'

###############################################################################
# BEGIN fix (28 / 244) for 'sysctl_net_ipv4_icmp_ignore_bogus_error_responses'
###############################################################################
(>&2 echo "Remediating rule 28/244: 'sysctl_net_ipv4_icmp_ignore_bogus_error_responses'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_icmp_ignore_bogus_error_responses' IS MISSING!")

# END fix for 'sysctl_net_ipv4_icmp_ignore_bogus_error_responses'

###############################################################################
# BEGIN fix (29 / 244) for 'sysctl_net_ipv4_conf_all_rp_filter'
###############################################################################
(>&2 echo "Remediating rule 29/244: 'sysctl_net_ipv4_conf_all_rp_filter'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_all_rp_filter' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_all_rp_filter'

###############################################################################
# BEGIN fix (30 / 244) for 'sysctl_net_ipv4_conf_default_accept_redirects'
###############################################################################
(>&2 echo "Remediating rule 30/244: 'sysctl_net_ipv4_conf_default_accept_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_default_accept_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_default_accept_redirects'

###############################################################################
# BEGIN fix (31 / 244) for 'sysctl_net_ipv4_conf_all_send_redirects'
###############################################################################
(>&2 echo "Remediating rule 31/244: 'sysctl_net_ipv4_conf_all_send_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_all_send_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_all_send_redirects'

###############################################################################
# BEGIN fix (32 / 244) for 'sysctl_net_ipv4_conf_default_send_redirects'
###############################################################################
(>&2 echo "Remediating rule 32/244: 'sysctl_net_ipv4_conf_default_send_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv4_conf_default_send_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv4_conf_default_send_redirects'

###############################################################################
# BEGIN fix (33 / 244) for 'sysctl_net_ipv6_conf_default_accept_ra'
###############################################################################
(>&2 echo "Remediating rule 33/244: 'sysctl_net_ipv6_conf_default_accept_ra'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv6_conf_default_accept_ra' IS MISSING!")

# END fix for 'sysctl_net_ipv6_conf_default_accept_ra'

###############################################################################
# BEGIN fix (34 / 244) for 'sysctl_net_ipv6_conf_default_accept_source_route'
###############################################################################
(>&2 echo "Remediating rule 34/244: 'sysctl_net_ipv6_conf_default_accept_source_route'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv6_conf_default_accept_source_route' IS MISSING!")

# END fix for 'sysctl_net_ipv6_conf_default_accept_source_route'

###############################################################################
# BEGIN fix (35 / 244) for 'sysctl_net_ipv6_conf_all_accept_redirects'
###############################################################################
(>&2 echo "Remediating rule 35/244: 'sysctl_net_ipv6_conf_all_accept_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv6_conf_all_accept_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv6_conf_all_accept_redirects'

###############################################################################
# BEGIN fix (36 / 244) for 'sysctl_net_ipv6_conf_all_accept_ra'
###############################################################################
(>&2 echo "Remediating rule 36/244: 'sysctl_net_ipv6_conf_all_accept_ra'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv6_conf_all_accept_ra' IS MISSING!")

# END fix for 'sysctl_net_ipv6_conf_all_accept_ra'

###############################################################################
# BEGIN fix (37 / 244) for 'sysctl_net_ipv6_conf_all_accept_source_route'
###############################################################################
(>&2 echo "Remediating rule 37/244: 'sysctl_net_ipv6_conf_all_accept_source_route'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv6_conf_all_accept_source_route' IS MISSING!")

# END fix for 'sysctl_net_ipv6_conf_all_accept_source_route'

###############################################################################
# BEGIN fix (38 / 244) for 'sysctl_net_ipv6_conf_default_accept_redirects'
###############################################################################
(>&2 echo "Remediating rule 38/244: 'sysctl_net_ipv6_conf_default_accept_redirects'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_ipv6_conf_default_accept_redirects' IS MISSING!")

# END fix for 'sysctl_net_ipv6_conf_default_accept_redirects'

###############################################################################
# BEGIN fix (39 / 244) for 'package_sudo_installed'
###############################################################################
(>&2 echo "Remediating rule 39/244: 'package_sudo_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_sudo_installed' IS MISSING!")

# END fix for 'package_sudo_installed'

###############################################################################
# BEGIN fix (40 / 244) for 'enable_fips_mode'
###############################################################################
(>&2 echo "Remediating rule 40/244: 'enable_fips_mode'")
(>&2 echo "FIX FOR THIS RULE 'enable_fips_mode' IS MISSING!")

# END fix for 'enable_fips_mode'

###############################################################################
# BEGIN fix (41 / 244) for 'enable_dracut_fips_module'
###############################################################################
(>&2 echo "Remediating rule 41/244: 'enable_dracut_fips_module'")
(>&2 echo "FIX FOR THIS RULE 'enable_dracut_fips_module' IS MISSING!")

# END fix for 'enable_dracut_fips_module'

###############################################################################
# BEGIN fix (42 / 244) for 'configure_crypto_policy'
###############################################################################
(>&2 echo "Remediating rule 42/244: 'configure_crypto_policy'")
(>&2 echo "FIX FOR THIS RULE 'configure_crypto_policy' IS MISSING!")

# END fix for 'configure_crypto_policy'

###############################################################################
# BEGIN fix (43 / 244) for 'harden_sshd_crypto_policy'
###############################################################################
(>&2 echo "Remediating rule 43/244: 'harden_sshd_crypto_policy'")
(>&2 echo "FIX FOR THIS RULE 'harden_sshd_crypto_policy' IS MISSING!")

# END fix for 'harden_sshd_crypto_policy'

###############################################################################
# BEGIN fix (44 / 244) for 'harden_ssh_client_crypto_policy'
###############################################################################
(>&2 echo "Remediating rule 44/244: 'harden_ssh_client_crypto_policy'")
(>&2 echo "FIX FOR THIS RULE 'harden_ssh_client_crypto_policy' IS MISSING!")

# END fix for 'harden_ssh_client_crypto_policy'

###############################################################################
# BEGIN fix (45 / 244) for 'configure_openssl_crypto_policy'
###############################################################################
(>&2 echo "Remediating rule 45/244: 'configure_openssl_crypto_policy'")
(>&2 echo "FIX FOR THIS RULE 'configure_openssl_crypto_policy' IS MISSING!")

# END fix for 'configure_openssl_crypto_policy'

###############################################################################
# BEGIN fix (46 / 244) for 'configure_kerberos_crypto_policy'
###############################################################################
(>&2 echo "Remediating rule 46/244: 'configure_kerberos_crypto_policy'")
(>&2 echo "FIX FOR THIS RULE 'configure_kerberos_crypto_policy' IS MISSING!")

# END fix for 'configure_kerberos_crypto_policy'

###############################################################################
# BEGIN fix (47 / 244) for 'rpm_verify_permissions'
###############################################################################
(>&2 echo "Remediating rule 47/244: 'rpm_verify_permissions'")
(>&2 echo "FIX FOR THIS RULE 'rpm_verify_permissions' IS MISSING!")

# END fix for 'rpm_verify_permissions'

###############################################################################
# BEGIN fix (48 / 244) for 'rpm_verify_ownership'
###############################################################################
(>&2 echo "Remediating rule 48/244: 'rpm_verify_ownership'")
(>&2 echo "FIX FOR THIS RULE 'rpm_verify_ownership' IS MISSING!")

# END fix for 'rpm_verify_ownership'

###############################################################################
# BEGIN fix (49 / 244) for 'sysctl_fs_protected_hardlinks'
###############################################################################
(>&2 echo "Remediating rule 49/244: 'sysctl_fs_protected_hardlinks'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_fs_protected_hardlinks' IS MISSING!")

# END fix for 'sysctl_fs_protected_hardlinks'

###############################################################################
# BEGIN fix (50 / 244) for 'sysctl_fs_protected_symlinks'
###############################################################################
(>&2 echo "Remediating rule 50/244: 'sysctl_fs_protected_symlinks'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_fs_protected_symlinks' IS MISSING!")

# END fix for 'sysctl_fs_protected_symlinks'

###############################################################################
# BEGIN fix (51 / 244) for 'sysctl_net_core_bpf_jit_harden'
###############################################################################
(>&2 echo "Remediating rule 51/244: 'sysctl_net_core_bpf_jit_harden'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_net_core_bpf_jit_harden' IS MISSING!")

# END fix for 'sysctl_net_core_bpf_jit_harden'

###############################################################################
# BEGIN fix (52 / 244) for 'sysctl_kernel_kexec_load_disabled'
###############################################################################
(>&2 echo "Remediating rule 52/244: 'sysctl_kernel_kexec_load_disabled'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_kexec_load_disabled' IS MISSING!")

# END fix for 'sysctl_kernel_kexec_load_disabled'

###############################################################################
# BEGIN fix (53 / 244) for 'sysctl_kernel_perf_event_paranoid'
###############################################################################
(>&2 echo "Remediating rule 53/244: 'sysctl_kernel_perf_event_paranoid'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_perf_event_paranoid' IS MISSING!")

# END fix for 'sysctl_kernel_perf_event_paranoid'

###############################################################################
# BEGIN fix (54 / 244) for 'sysctl_kernel_dmesg_restrict'
###############################################################################
(>&2 echo "Remediating rule 54/244: 'sysctl_kernel_dmesg_restrict'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_dmesg_restrict' IS MISSING!")

# END fix for 'sysctl_kernel_dmesg_restrict'

###############################################################################
# BEGIN fix (55 / 244) for 'sysctl_kernel_core_pattern'
###############################################################################
(>&2 echo "Remediating rule 55/244: 'sysctl_kernel_core_pattern'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_core_pattern' IS MISSING!")

# END fix for 'sysctl_kernel_core_pattern'

###############################################################################
# BEGIN fix (56 / 244) for 'sysctl_kernel_yama_ptrace_scope'
###############################################################################
(>&2 echo "Remediating rule 56/244: 'sysctl_kernel_yama_ptrace_scope'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_yama_ptrace_scope' IS MISSING!")

# END fix for 'sysctl_kernel_yama_ptrace_scope'

###############################################################################
# BEGIN fix (57 / 244) for 'grub2_vsyscall_argument'
###############################################################################
(>&2 echo "Remediating rule 57/244: 'grub2_vsyscall_argument'")
(>&2 echo "FIX FOR THIS RULE 'grub2_vsyscall_argument' IS MISSING!")

# END fix for 'grub2_vsyscall_argument'

###############################################################################
# BEGIN fix (58 / 244) for 'sysctl_kernel_unprivileged_bpf_disabled'
###############################################################################
(>&2 echo "Remediating rule 58/244: 'sysctl_kernel_unprivileged_bpf_disabled'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_unprivileged_bpf_disabled' IS MISSING!")

# END fix for 'sysctl_kernel_unprivileged_bpf_disabled'

###############################################################################
# BEGIN fix (59 / 244) for 'sysctl_user_max_user_namespaces'
###############################################################################
(>&2 echo "Remediating rule 59/244: 'sysctl_user_max_user_namespaces'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_user_max_user_namespaces' IS MISSING!")

# END fix for 'sysctl_user_max_user_namespaces'

###############################################################################
# BEGIN fix (60 / 244) for 'sysctl_kernel_kptr_restrict'
###############################################################################
(>&2 echo "Remediating rule 60/244: 'sysctl_kernel_kptr_restrict'")
(>&2 echo "FIX FOR THIS RULE 'sysctl_kernel_kptr_restrict' IS MISSING!")

# END fix for 'sysctl_kernel_kptr_restrict'

###############################################################################
# BEGIN fix (61 / 244) for 'service_systemd-coredump_disabled'
###############################################################################
(>&2 echo "Remediating rule 61/244: 'service_systemd-coredump_disabled'")
(>&2 echo "FIX FOR THIS RULE 'service_systemd-coredump_disabled' IS MISSING!")

# END fix for 'service_systemd-coredump_disabled'

###############################################################################
# BEGIN fix (62 / 244) for 'coredump_disable_backtraces'
###############################################################################
(>&2 echo "Remediating rule 62/244: 'coredump_disable_backtraces'")
if [ -e "/etc/systemd/coredump.conf" ] ; then
    LC_ALL=C sed -i "/^\s*ProcessSizeMax\s*=\s*/Id" "/etc/systemd/coredump.conf"
else
    touch "/etc/systemd/coredump.conf"
fi
cp "/etc/systemd/coredump.conf" "/etc/systemd/coredump.conf.bak"
# Insert at the end of the file
printf '%s\n' "ProcessSizeMax=0" >> "/etc/systemd/coredump.conf"
# Clean up after ourselves.
rm "/etc/systemd/coredump.conf.bak"

# END fix for 'coredump_disable_backtraces'

###############################################################################
# BEGIN fix (63 / 244) for 'coredump_disable_storage'
###############################################################################
(>&2 echo "Remediating rule 63/244: 'coredump_disable_storage'")
if [ -e "/etc/systemd/coredump.conf" ] ; then
    LC_ALL=C sed -i "/^\s*Storage\s*=\s*/Id" "/etc/systemd/coredump.conf"
else
    touch "/etc/systemd/coredump.conf"
fi
cp "/etc/systemd/coredump.conf" "/etc/systemd/coredump.conf.bak"
# Insert at the end of the file
printf '%s\n' "Storage=none" >> "/etc/systemd/coredump.conf"
# Clean up after ourselves.
rm "/etc/systemd/coredump.conf.bak"

# END fix for 'coredump_disable_storage'

###############################################################################
# BEGIN fix (64 / 244) for 'disable_users_coredumps'
###############################################################################
(>&2 echo "Remediating rule 64/244: 'disable_users_coredumps'")
(>&2 echo "FIX FOR THIS RULE 'disable_users_coredumps' IS MISSING!")

# END fix for 'disable_users_coredumps'

###############################################################################
# BEGIN fix (65 / 244) for 'grub2_page_poison_argument'
###############################################################################
(>&2 echo "Remediating rule 65/244: 'grub2_page_poison_argument'")
(>&2 echo "FIX FOR THIS RULE 'grub2_page_poison_argument' IS MISSING!")

# END fix for 'grub2_page_poison_argument'

###############################################################################
# BEGIN fix (66 / 244) for 'grub2_slub_debug_argument'
###############################################################################
(>&2 echo "Remediating rule 66/244: 'grub2_slub_debug_argument'")
(>&2 echo "FIX FOR THIS RULE 'grub2_slub_debug_argument' IS MISSING!")

# END fix for 'grub2_slub_debug_argument'

###############################################################################
# BEGIN fix (67 / 244) for 'service_autofs_disabled'
###############################################################################
(>&2 echo "Remediating rule 67/244: 'service_autofs_disabled'")
(>&2 echo "FIX FOR THIS RULE 'service_autofs_disabled' IS MISSING!")

# END fix for 'service_autofs_disabled'

###############################################################################
# BEGIN fix (68 / 244) for 'kernel_module_hfs_disabled'
###############################################################################
(>&2 echo "Remediating rule 68/244: 'kernel_module_hfs_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_hfs_disabled' IS MISSING!")

# END fix for 'kernel_module_hfs_disabled'

###############################################################################
# BEGIN fix (69 / 244) for 'bios_disable_usb_boot'
###############################################################################
(>&2 echo "Remediating rule 69/244: 'bios_disable_usb_boot'")
(>&2 echo "FIX FOR THIS RULE 'bios_disable_usb_boot' IS MISSING!")

# END fix for 'bios_disable_usb_boot'

###############################################################################
# BEGIN fix (70 / 244) for 'kernel_module_freevxfs_disabled'
###############################################################################
(>&2 echo "Remediating rule 70/244: 'kernel_module_freevxfs_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_freevxfs_disabled' IS MISSING!")

# END fix for 'kernel_module_freevxfs_disabled'

###############################################################################
# BEGIN fix (71 / 244) for 'kernel_module_usb-storage_disabled'
###############################################################################
(>&2 echo "Remediating rule 71/244: 'kernel_module_usb-storage_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_usb-storage_disabled' IS MISSING!")

# END fix for 'kernel_module_usb-storage_disabled'

###############################################################################
# BEGIN fix (72 / 244) for 'kernel_module_cramfs_disabled'
###############################################################################
(>&2 echo "Remediating rule 72/244: 'kernel_module_cramfs_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_cramfs_disabled' IS MISSING!")

# END fix for 'kernel_module_cramfs_disabled'

###############################################################################
# BEGIN fix (73 / 244) for 'kernel_module_jffs2_disabled'
###############################################################################
(>&2 echo "Remediating rule 73/244: 'kernel_module_jffs2_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_jffs2_disabled' IS MISSING!")

# END fix for 'kernel_module_jffs2_disabled'

###############################################################################
# BEGIN fix (74 / 244) for 'kernel_module_vfat_disabled'
###############################################################################
(>&2 echo "Remediating rule 74/244: 'kernel_module_vfat_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_vfat_disabled' IS MISSING!")

# END fix for 'kernel_module_vfat_disabled'

###############################################################################
# BEGIN fix (75 / 244) for 'kernel_module_hfsplus_disabled'
###############################################################################
(>&2 echo "Remediating rule 75/244: 'kernel_module_hfsplus_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_hfsplus_disabled' IS MISSING!")

# END fix for 'kernel_module_hfsplus_disabled'

###############################################################################
# BEGIN fix (76 / 244) for 'kernel_module_squashfs_disabled'
###############################################################################
(>&2 echo "Remediating rule 76/244: 'kernel_module_squashfs_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_squashfs_disabled' IS MISSING!")

# END fix for 'kernel_module_squashfs_disabled'

###############################################################################
# BEGIN fix (77 / 244) for 'kernel_module_udf_disabled'
###############################################################################
(>&2 echo "Remediating rule 77/244: 'kernel_module_udf_disabled'")
(>&2 echo "FIX FOR THIS RULE 'kernel_module_udf_disabled' IS MISSING!")

# END fix for 'kernel_module_udf_disabled'

###############################################################################
# BEGIN fix (78 / 244) for 'grub2_nousb_argument'
###############################################################################
(>&2 echo "Remediating rule 78/244: 'grub2_nousb_argument'")
(>&2 echo "FIX FOR THIS RULE 'grub2_nousb_argument' IS MISSING!")

# END fix for 'grub2_nousb_argument'

###############################################################################
# BEGIN fix (79 / 244) for 'banner_etc_issue'
###############################################################################
(>&2 echo "Remediating rule 79/244: 'banner_etc_issue'")
(>&2 echo "FIX FOR THIS RULE 'banner_etc_issue' IS MISSING!")

# END fix for 'banner_etc_issue'

###############################################################################
# BEGIN fix (80 / 244) for 'service_debug-shell_disabled'
###############################################################################
(>&2 echo "Remediating rule 80/244: 'service_debug-shell_disabled'")
(>&2 echo "FIX FOR THIS RULE 'service_debug-shell_disabled' IS MISSING!")

# END fix for 'service_debug-shell_disabled'

###############################################################################
# BEGIN fix (81 / 244) for 'require_singleuser_auth'
###############################################################################
(>&2 echo "Remediating rule 81/244: 'require_singleuser_auth'")
(>&2 echo "FIX FOR THIS RULE 'require_singleuser_auth' IS MISSING!")

# END fix for 'require_singleuser_auth'

###############################################################################
# BEGIN fix (82 / 244) for 'grub2_disable_interactive_boot'
###############################################################################
(>&2 echo "Remediating rule 82/244: 'grub2_disable_interactive_boot'")
(>&2 echo "FIX FOR THIS RULE 'grub2_disable_interactive_boot' IS MISSING!")

# END fix for 'grub2_disable_interactive_boot'

###############################################################################
# BEGIN fix (83 / 244) for 'disable_ctrlaltdel_reboot'
###############################################################################
(>&2 echo "Remediating rule 83/244: 'disable_ctrlaltdel_reboot'")
(>&2 echo "FIX FOR THIS RULE 'disable_ctrlaltdel_reboot' IS MISSING!")

# END fix for 'disable_ctrlaltdel_reboot'

###############################################################################
# BEGIN fix (84 / 244) for 'disable_ctrlaltdel_burstaction'
###############################################################################
(>&2 echo "Remediating rule 84/244: 'disable_ctrlaltdel_burstaction'")
(>&2 echo "FIX FOR THIS RULE 'disable_ctrlaltdel_burstaction' IS MISSING!")

# END fix for 'disable_ctrlaltdel_burstaction'

###############################################################################
# BEGIN fix (85 / 244) for 'account_disable_post_pw_expiration'
###############################################################################
(>&2 echo "Remediating rule 85/244: 'account_disable_post_pw_expiration'")
(>&2 echo "FIX FOR THIS RULE 'account_disable_post_pw_expiration' IS MISSING!")

# END fix for 'account_disable_post_pw_expiration'

###############################################################################
# BEGIN fix (86 / 244) for 'no_empty_passwords'
###############################################################################
(>&2 echo "Remediating rule 86/244: 'no_empty_passwords'")
(>&2 echo "FIX FOR THIS RULE 'no_empty_passwords' IS MISSING!")

# END fix for 'no_empty_passwords'

###############################################################################
# BEGIN fix (87 / 244) for 'no_netrc_files'
###############################################################################
(>&2 echo "Remediating rule 87/244: 'no_netrc_files'")
(>&2 echo "FIX FOR THIS RULE 'no_netrc_files' IS MISSING!")

# END fix for 'no_netrc_files'

###############################################################################
# BEGIN fix (88 / 244) for 'no_shelllogin_for_systemaccounts'
###############################################################################
(>&2 echo "Remediating rule 88/244: 'no_shelllogin_for_systemaccounts'")
(>&2 echo "FIX FOR THIS RULE 'no_shelllogin_for_systemaccounts' IS MISSING!")

# END fix for 'no_shelllogin_for_systemaccounts'

###############################################################################
# BEGIN fix (89 / 244) for 'accounts_no_uid_except_zero'
###############################################################################
(>&2 echo "Remediating rule 89/244: 'accounts_no_uid_except_zero'")
(>&2 echo "FIX FOR THIS RULE 'accounts_no_uid_except_zero' IS MISSING!")

# END fix for 'accounts_no_uid_except_zero'

###############################################################################
# BEGIN fix (90 / 244) for 'no_direct_root_logins'
###############################################################################
(>&2 echo "Remediating rule 90/244: 'no_direct_root_logins'")
echo > /etc/securetty

# END fix for 'no_direct_root_logins'

###############################################################################
# BEGIN fix (91 / 244) for 'package_audit_installed'
###############################################################################
(>&2 echo "Remediating rule 91/244: 'package_audit_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_audit_installed' IS MISSING!")

# END fix for 'package_audit_installed'

###############################################################################
# BEGIN fix (92 / 244) for 'service_auditd_enabled'
###############################################################################
(>&2 echo "Remediating rule 92/244: 'service_auditd_enabled'")
(>&2 echo "FIX FOR THIS RULE 'service_auditd_enabled' IS MISSING!")

# END fix for 'service_auditd_enabled'

###############################################################################
# BEGIN fix (93 / 244) for 'grub2_audit_argument'
###############################################################################
(>&2 echo "Remediating rule 93/244: 'grub2_audit_argument'")
(>&2 echo "FIX FOR THIS RULE 'grub2_audit_argument' IS MISSING!")

# END fix for 'grub2_audit_argument'

###############################################################################
# BEGIN fix (94 / 244) for 'grub2_audit_backlog_limit_argument'
###############################################################################
(>&2 echo "Remediating rule 94/244: 'grub2_audit_backlog_limit_argument'")
(>&2 echo "FIX FOR THIS RULE 'grub2_audit_backlog_limit_argument' IS MISSING!")

# END fix for 'grub2_audit_backlog_limit_argument'

###############################################################################
# BEGIN fix (95 / 244) for 'auditd_data_retention_space_left_action'
###############################################################################
(>&2 echo "Remediating rule 95/244: 'auditd_data_retention_space_left_action'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_retention_space_left_action' IS MISSING!")

# END fix for 'auditd_data_retention_space_left_action'

###############################################################################
# BEGIN fix (96 / 244) for 'auditd_freq'
###############################################################################
(>&2 echo "Remediating rule 96/244: 'auditd_freq'")
if [ -e "/etc/audit/auditd.conf" ] ; then
    LC_ALL=C sed -i "/^\s*freq\s*=\s*/Id" "/etc/audit/auditd.conf"
else
    touch "/etc/audit/auditd.conf"
fi
cp "/etc/audit/auditd.conf" "/etc/audit/auditd.conf.bak"
# Insert at the end of the file
printf '%s\n' "freq = 50" >> "/etc/audit/auditd.conf"
# Clean up after ourselves.
rm "/etc/audit/auditd.conf.bak"

# END fix for 'auditd_freq'

###############################################################################
# BEGIN fix (97 / 244) for 'auditd_name_format'
###############################################################################
(>&2 echo "Remediating rule 97/244: 'auditd_name_format'")
if [ -e "/etc/audit/auditd.conf" ] ; then
    LC_ALL=C sed -i "/^\s*name_format\s*=\s*/Id" "/etc/audit/auditd.conf"
else
    touch "/etc/audit/auditd.conf"
fi
cp "/etc/audit/auditd.conf" "/etc/audit/auditd.conf.bak"
# Insert at the end of the file
printf '%s\n' "name_format = hostname" >> "/etc/audit/auditd.conf"
# Clean up after ourselves.
rm "/etc/audit/auditd.conf.bak"

# END fix for 'auditd_name_format'

###############################################################################
# BEGIN fix (98 / 244) for 'auditd_log_format'
###############################################################################
(>&2 echo "Remediating rule 98/244: 'auditd_log_format'")
if [ -e "/etc/audit/auditd.conf" ] ; then
    LC_ALL=C sed -i "/^\s*log_format\s*=\s*/Id" "/etc/audit/auditd.conf"
else
    touch "/etc/audit/auditd.conf"
fi
cp "/etc/audit/auditd.conf" "/etc/audit/auditd.conf.bak"
# Insert at the end of the file
printf '%s\n' "log_format = ENRICHED" >> "/etc/audit/auditd.conf"
# Clean up after ourselves.
rm "/etc/audit/auditd.conf.bak"

# END fix for 'auditd_log_format'

###############################################################################
# BEGIN fix (99 / 244) for 'auditd_data_retention_flush'
###############################################################################
(>&2 echo "Remediating rule 99/244: 'auditd_data_retention_flush'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_retention_flush' IS MISSING!")

# END fix for 'auditd_data_retention_flush'

###############################################################################
# BEGIN fix (100 / 244) for 'auditd_data_retention_num_logs'
###############################################################################
(>&2 echo "Remediating rule 100/244: 'auditd_data_retention_num_logs'")

var_auditd_num_logs="5"

AUDITCONFIG=/etc/audit/auditd.conf
# Function to replace configuration setting in config file or add the configuration setting if
# it does not exist.
#
# Expects arguments:
#
# config_file:		Configuration file that will be modified
# key:			Configuration option to change
# value:		Value of the configuration option to change
# cce:			The CCE identifier or '@CCENUM@' if no CCE identifier exists
# format:		The printf-like format string that will be given stripped key and value as arguments,
#			so e.g. '%s=%s' will result in key=value subsitution (i.e. without spaces around =)
#
# Optional arugments:
#
# format:		Optional argument to specify the format of how key/value should be
# 			modified/appended in the configuration file. The default is key = value.
#
# Example Call(s):
#
#     With default format of 'key = value':
#     replace_or_append '/etc/sysctl.conf' '^kernel.randomize_va_space' '2' '@CCENUM@'
#
#     With custom key/value format:
#     replace_or_append '/etc/sysconfig/selinux' '^SELINUX=' 'disabled' '@CCENUM@' '%s=%s'
#
#     With a variable:
#     replace_or_append '/etc/sysconfig/selinux' '^SELINUX=' $var_selinux_state '@CCENUM@' '%s=%s'
#
function replace_or_append {
  local default_format='%s = %s' case_insensitive_mode=yes sed_case_insensitive_option='' grep_case_insensitive_option=''
  local config_file=$1
  local key=$2
  local value=$3
  local cce=$4
  local format=$5

  if [ "$case_insensitive_mode" = yes ]; then
    sed_case_insensitive_option="i"
    grep_case_insensitive_option="-i"
  fi
  [ -n "$format" ] || format="$default_format"
  # Check sanity of the input
  [ $# -ge "3" ] || { echo "Usage: replace_or_append <config_file_location> <key_to_search> <new_value> [<CCE number or literal '@CCENUM@' if unknown>] [printf-like format, default is '$default_format']" >&2; exit 1; }

  # Test if the config_file is a symbolic link. If so, use --follow-symlinks with sed.
  # Otherwise, regular sed command will do.
  sed_command=('sed' '-i')
  if test -L "$config_file"; then
    sed_command+=('--follow-symlinks')
  fi

  # Test that the cce arg is not empty or does not equal @CCENUM@.
  # If @CCENUM@ exists, it means that there is no CCE assigned.
  if [ -n "$cce" ] && [ "$cce" != '@CCENUM@' ]; then
    cce="${cce}"
  else
    cce="CCE"
  fi

  # Strip any search characters in the key arg so that the key can be replaced without
  # adding any search characters to the config file.
  stripped_key=$(sed 's/[\^=\$,;+]*//g' <<< "$key")

  # shellcheck disable=SC2059
  printf -v formatted_output "$format" "$stripped_key" "$value"

  # If the key exists, change it. Otherwise, add it to the config_file.
  # We search for the key string followed by a word boundary (matched by \>),
  # so if we search for 'setting', 'setting2' won't match.
  if LC_ALL=C grep -q -m 1 $grep_case_insensitive_option -e "${key}\\>" "$config_file"; then
    "${sed_command[@]}" "s/${key}\\>.*/$formatted_output/g$sed_case_insensitive_option" "$config_file"
  else
    # \n is precaution for case where file ends without trailing newline
    printf '\n# Per %s: Set %s in %s\n' "$cce" "$formatted_output" "$config_file" >> "$config_file"
    printf '%s\n' "$formatted_output" >> "$config_file"
  fi
}
replace_or_append $AUDITCONFIG '^num_logs' "$var_auditd_num_logs" "@CCENUM@"

# END fix for 'auditd_data_retention_num_logs'

###############################################################################
# BEGIN fix (101 / 244) for 'auditd_data_retention_action_mail_acct'
###############################################################################
(>&2 echo "Remediating rule 101/244: 'auditd_data_retention_action_mail_acct'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_retention_action_mail_acct' IS MISSING!")

# END fix for 'auditd_data_retention_action_mail_acct'

###############################################################################
# BEGIN fix (102 / 244) for 'auditd_data_retention_space_left'
###############################################################################
(>&2 echo "Remediating rule 102/244: 'auditd_data_retention_space_left'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_retention_space_left' IS MISSING!")

# END fix for 'auditd_data_retention_space_left'

###############################################################################
# BEGIN fix (103 / 244) for 'auditd_data_retention_max_log_file_action'
###############################################################################
(>&2 echo "Remediating rule 103/244: 'auditd_data_retention_max_log_file_action'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_retention_max_log_file_action' IS MISSING!")

# END fix for 'auditd_data_retention_max_log_file_action'

###############################################################################
# BEGIN fix (104 / 244) for 'auditd_write_logs'
###############################################################################
(>&2 echo "Remediating rule 104/244: 'auditd_write_logs'")
if [ -e "/etc/audit/auditd.conf" ] ; then
    LC_ALL=C sed -i "/^\s*write_logs\s*=\s*/Id" "/etc/audit/auditd.conf"
else
    touch "/etc/audit/auditd.conf"
fi
cp "/etc/audit/auditd.conf" "/etc/audit/auditd.conf.bak"
# Insert at the end of the file
printf '%s\n' "write_logs = yes" >> "/etc/audit/auditd.conf"
# Clean up after ourselves.
rm "/etc/audit/auditd.conf.bak"

# END fix for 'auditd_write_logs'

###############################################################################
# BEGIN fix (105 / 244) for 'auditd_data_disk_error_action'
###############################################################################
(>&2 echo "Remediating rule 105/244: 'auditd_data_disk_error_action'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_disk_error_action' IS MISSING!")

# END fix for 'auditd_data_disk_error_action'

###############################################################################
# BEGIN fix (106 / 244) for 'auditd_data_disk_full_action'
###############################################################################
(>&2 echo "Remediating rule 106/244: 'auditd_data_disk_full_action'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_disk_full_action' IS MISSING!")

# END fix for 'auditd_data_disk_full_action'

###############################################################################
# BEGIN fix (107 / 244) for 'auditd_local_events'
###############################################################################
(>&2 echo "Remediating rule 107/244: 'auditd_local_events'")
if [ -e "/etc/audit/auditd.conf" ] ; then
    LC_ALL=C sed -i "/^\s*local_events\s*=\s*/Id" "/etc/audit/auditd.conf"
else
    touch "/etc/audit/auditd.conf"
fi
cp "/etc/audit/auditd.conf" "/etc/audit/auditd.conf.bak"
# Insert at the end of the file
printf '%s\n' "local_events = yes" >> "/etc/audit/auditd.conf"
# Clean up after ourselves.
rm "/etc/audit/auditd.conf.bak"

# END fix for 'auditd_local_events'

###############################################################################
# BEGIN fix (108 / 244) for 'auditd_data_retention_admin_space_left_action'
###############################################################################
(>&2 echo "Remediating rule 108/244: 'auditd_data_retention_admin_space_left_action'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_retention_admin_space_left_action' IS MISSING!")

# END fix for 'auditd_data_retention_admin_space_left_action'

###############################################################################
# BEGIN fix (109 / 244) for 'auditd_data_retention_max_log_file'
###############################################################################
(>&2 echo "Remediating rule 109/244: 'auditd_data_retention_max_log_file'")
(>&2 echo "FIX FOR THIS RULE 'auditd_data_retention_max_log_file' IS MISSING!")

# END fix for 'auditd_data_retention_max_log_file'

###############################################################################
# BEGIN fix (110 / 244) for 'directory_permissions_var_log_audit'
###############################################################################
(>&2 echo "Remediating rule 110/244: 'directory_permissions_var_log_audit'")
(>&2 echo "FIX FOR THIS RULE 'directory_permissions_var_log_audit' IS MISSING!")

# END fix for 'directory_permissions_var_log_audit'

###############################################################################
# BEGIN fix (111 / 244) for 'audit_rules_usergroup_modification_group'
###############################################################################
(>&2 echo "Remediating rule 111/244: 'audit_rules_usergroup_modification_group'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_usergroup_modification_group' IS MISSING!")

# END fix for 'audit_rules_usergroup_modification_group'

###############################################################################
# BEGIN fix (112 / 244) for 'audit_rules_session_events'
###############################################################################
(>&2 echo "Remediating rule 112/244: 'audit_rules_session_events'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_session_events' IS MISSING!")

# END fix for 'audit_rules_session_events'

###############################################################################
# BEGIN fix (113 / 244) for 'audit_rules_usergroup_modification_gshadow'
###############################################################################
(>&2 echo "Remediating rule 113/244: 'audit_rules_usergroup_modification_gshadow'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_usergroup_modification_gshadow' IS MISSING!")

# END fix for 'audit_rules_usergroup_modification_gshadow'

###############################################################################
# BEGIN fix (114 / 244) for 'audit_rules_etc_passwd_openat'
###############################################################################
(>&2 echo "Remediating rule 114/244: 'audit_rules_etc_passwd_openat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_passwd_openat' IS MISSING!")

# END fix for 'audit_rules_etc_passwd_openat'

###############################################################################
# BEGIN fix (115 / 244) for 'audit_rules_etc_shadow_openat'
###############################################################################
(>&2 echo "Remediating rule 115/244: 'audit_rules_etc_shadow_openat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_shadow_openat' IS MISSING!")

# END fix for 'audit_rules_etc_shadow_openat'

###############################################################################
# BEGIN fix (116 / 244) for 'file_ownership_var_log_audit'
###############################################################################
(>&2 echo "Remediating rule 116/244: 'file_ownership_var_log_audit'")

if LC_ALL=C grep -m 1 -q ^log_group /etc/audit/auditd.conf; then
  GROUP=$(awk -F "=" '/log_group/ {print $2}' /etc/audit/auditd.conf | tr -d ' ')
  if ! [ "${GROUP}" == 'root' ] ; then
    chown root.${GROUP} /var/log/audit
    chown root.${GROUP} /var/log/audit/audit.log*
  else
    chown root.root /var/log/audit
    chown root.root /var/log/audit/audit.log*
  fi
else
  chown root.root /var/log/audit
  chown root.root /var/log/audit/audit.log*
fi

# END fix for 'file_ownership_var_log_audit'

###############################################################################
# BEGIN fix (117 / 244) for 'audit_rules_etc_gshadow_open_by_handle_at'
###############################################################################
(>&2 echo "Remediating rule 117/244: 'audit_rules_etc_gshadow_open_by_handle_at'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_gshadow_open_by_handle_at' IS MISSING!")

# END fix for 'audit_rules_etc_gshadow_open_by_handle_at'

###############################################################################
# BEGIN fix (118 / 244) for 'audit_rules_etc_gshadow_openat'
###############################################################################
(>&2 echo "Remediating rule 118/244: 'audit_rules_etc_gshadow_openat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_gshadow_openat' IS MISSING!")

# END fix for 'audit_rules_etc_gshadow_openat'

###############################################################################
# BEGIN fix (119 / 244) for 'audit_rules_etc_shadow_open'
###############################################################################
(>&2 echo "Remediating rule 119/244: 'audit_rules_etc_shadow_open'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_shadow_open' IS MISSING!")

# END fix for 'audit_rules_etc_shadow_open'

###############################################################################
# BEGIN fix (120 / 244) for 'audit_rules_sysadmin_actions'
###############################################################################
(>&2 echo "Remediating rule 120/244: 'audit_rules_sysadmin_actions'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_sysadmin_actions' IS MISSING!")

# END fix for 'audit_rules_sysadmin_actions'

###############################################################################
# BEGIN fix (121 / 244) for 'audit_rules_etc_passwd_open'
###############################################################################
(>&2 echo "Remediating rule 121/244: 'audit_rules_etc_passwd_open'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_passwd_open' IS MISSING!")

# END fix for 'audit_rules_etc_passwd_open'

###############################################################################
# BEGIN fix (122 / 244) for 'audit_rules_usergroup_modification_passwd'
###############################################################################
(>&2 echo "Remediating rule 122/244: 'audit_rules_usergroup_modification_passwd'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_usergroup_modification_passwd' IS MISSING!")

# END fix for 'audit_rules_usergroup_modification_passwd'

###############################################################################
# BEGIN fix (123 / 244) for 'audit_rules_networkconfig_modification'
###############################################################################
(>&2 echo "Remediating rule 123/244: 'audit_rules_networkconfig_modification'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_networkconfig_modification' IS MISSING!")

# END fix for 'audit_rules_networkconfig_modification'

###############################################################################
# BEGIN fix (124 / 244) for 'file_permissions_var_log_audit'
###############################################################################
(>&2 echo "Remediating rule 124/244: 'file_permissions_var_log_audit'")
(>&2 echo "FIX FOR THIS RULE 'file_permissions_var_log_audit' IS MISSING!")

# END fix for 'file_permissions_var_log_audit'

###############################################################################
# BEGIN fix (125 / 244) for 'audit_rules_etc_passwd_open_by_handle_at'
###############################################################################
(>&2 echo "Remediating rule 125/244: 'audit_rules_etc_passwd_open_by_handle_at'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_passwd_open_by_handle_at' IS MISSING!")

# END fix for 'audit_rules_etc_passwd_open_by_handle_at'

###############################################################################
# BEGIN fix (126 / 244) for 'audit_rules_etc_group_open_by_handle_at'
###############################################################################
(>&2 echo "Remediating rule 126/244: 'audit_rules_etc_group_open_by_handle_at'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_group_open_by_handle_at' IS MISSING!")

# END fix for 'audit_rules_etc_group_open_by_handle_at'

###############################################################################
# BEGIN fix (127 / 244) for 'audit_rules_media_export'
###############################################################################
(>&2 echo "Remediating rule 127/244: 'audit_rules_media_export'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_media_export' IS MISSING!")

# END fix for 'audit_rules_media_export'

###############################################################################
# BEGIN fix (128 / 244) for 'audit_rules_mac_modification'
###############################################################################
(>&2 echo "Remediating rule 128/244: 'audit_rules_mac_modification'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_mac_modification' IS MISSING!")

# END fix for 'audit_rules_mac_modification'

###############################################################################
# BEGIN fix (129 / 244) for 'audit_rules_etc_shadow_open_by_handle_at'
###############################################################################
(>&2 echo "Remediating rule 129/244: 'audit_rules_etc_shadow_open_by_handle_at'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_shadow_open_by_handle_at' IS MISSING!")

# END fix for 'audit_rules_etc_shadow_open_by_handle_at'

###############################################################################
# BEGIN fix (130 / 244) for 'audit_rules_etc_group_open'
###############################################################################
(>&2 echo "Remediating rule 130/244: 'audit_rules_etc_group_open'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_group_open' IS MISSING!")

# END fix for 'audit_rules_etc_group_open'

###############################################################################
# BEGIN fix (131 / 244) for 'audit_rules_usergroup_modification_shadow'
###############################################################################
(>&2 echo "Remediating rule 131/244: 'audit_rules_usergroup_modification_shadow'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_usergroup_modification_shadow' IS MISSING!")

# END fix for 'audit_rules_usergroup_modification_shadow'

###############################################################################
# BEGIN fix (132 / 244) for 'audit_rules_etc_group_openat'
###############################################################################
(>&2 echo "Remediating rule 132/244: 'audit_rules_etc_group_openat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_group_openat' IS MISSING!")

# END fix for 'audit_rules_etc_group_openat'

###############################################################################
# BEGIN fix (133 / 244) for 'audit_rules_etc_gshadow_open'
###############################################################################
(>&2 echo "Remediating rule 133/244: 'audit_rules_etc_gshadow_open'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_etc_gshadow_open' IS MISSING!")

# END fix for 'audit_rules_etc_gshadow_open'

###############################################################################
# BEGIN fix (134 / 244) for 'audit_rules_immutable'
###############################################################################
(>&2 echo "Remediating rule 134/244: 'audit_rules_immutable'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_immutable' IS MISSING!")

# END fix for 'audit_rules_immutable'

###############################################################################
# BEGIN fix (135 / 244) for 'audit_rules_usergroup_modification_opasswd'
###############################################################################
(>&2 echo "Remediating rule 135/244: 'audit_rules_usergroup_modification_opasswd'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_usergroup_modification_opasswd' IS MISSING!")

# END fix for 'audit_rules_usergroup_modification_opasswd'

###############################################################################
# BEGIN fix (136 / 244) for 'directory_access_var_log_audit'
###############################################################################
(>&2 echo "Remediating rule 136/244: 'directory_access_var_log_audit'")
(>&2 echo "FIX FOR THIS RULE 'directory_access_var_log_audit' IS MISSING!")

# END fix for 'directory_access_var_log_audit'

###############################################################################
# BEGIN fix (137 / 244) for 'audit_rules_privileged_commands_pt_chown'
###############################################################################
(>&2 echo "Remediating rule 137/244: 'audit_rules_privileged_commands_pt_chown'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_pt_chown' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_pt_chown'

###############################################################################
# BEGIN fix (138 / 244) for 'audit_rules_privileged_commands_at'
###############################################################################
(>&2 echo "Remediating rule 138/244: 'audit_rules_privileged_commands_at'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_at' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_at'

###############################################################################
# BEGIN fix (139 / 244) for 'audit_rules_privileged_commands_newgidmap'
###############################################################################
(>&2 echo "Remediating rule 139/244: 'audit_rules_privileged_commands_newgidmap'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_newgidmap' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_newgidmap'

###############################################################################
# BEGIN fix (140 / 244) for 'audit_rules_privileged_commands_crontab'
###############################################################################
(>&2 echo "Remediating rule 140/244: 'audit_rules_privileged_commands_crontab'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_crontab' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_crontab'

###############################################################################
# BEGIN fix (141 / 244) for 'audit_rules_privileged_commands_pam_timestamp_check'
###############################################################################
(>&2 echo "Remediating rule 141/244: 'audit_rules_privileged_commands_pam_timestamp_check'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_pam_timestamp_check' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_pam_timestamp_check'

###############################################################################
# BEGIN fix (142 / 244) for 'audit_rules_privileged_commands_newgrp'
###############################################################################
(>&2 echo "Remediating rule 142/244: 'audit_rules_privileged_commands_newgrp'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_newgrp' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_newgrp'

###############################################################################
# BEGIN fix (143 / 244) for 'audit_rules_privileged_commands_chsh'
###############################################################################
(>&2 echo "Remediating rule 143/244: 'audit_rules_privileged_commands_chsh'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_chsh' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_chsh'

###############################################################################
# BEGIN fix (144 / 244) for 'audit_rules_privileged_commands'
###############################################################################
(>&2 echo "Remediating rule 144/244: 'audit_rules_privileged_commands'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands' IS MISSING!")

# END fix for 'audit_rules_privileged_commands'

###############################################################################
# BEGIN fix (145 / 244) for 'audit_rules_privileged_commands_sudoedit'
###############################################################################
(>&2 echo "Remediating rule 145/244: 'audit_rules_privileged_commands_sudoedit'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_sudoedit' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_sudoedit'

###############################################################################
# BEGIN fix (146 / 244) for 'audit_rules_privileged_commands_postqueue'
###############################################################################
(>&2 echo "Remediating rule 146/244: 'audit_rules_privileged_commands_postqueue'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_postqueue' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_postqueue'

###############################################################################
# BEGIN fix (147 / 244) for 'audit_rules_privileged_commands_gpasswd'
###############################################################################
(>&2 echo "Remediating rule 147/244: 'audit_rules_privileged_commands_gpasswd'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_gpasswd' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_gpasswd'

###############################################################################
# BEGIN fix (148 / 244) for 'audit_rules_privileged_commands_usernetctl'
###############################################################################
(>&2 echo "Remediating rule 148/244: 'audit_rules_privileged_commands_usernetctl'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_usernetctl' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_usernetctl'

###############################################################################
# BEGIN fix (149 / 244) for 'audit_rules_privileged_commands_chage'
###############################################################################
(>&2 echo "Remediating rule 149/244: 'audit_rules_privileged_commands_chage'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_chage' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_chage'

###############################################################################
# BEGIN fix (150 / 244) for 'audit_rules_privileged_commands_mount'
###############################################################################
(>&2 echo "Remediating rule 150/244: 'audit_rules_privileged_commands_mount'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_mount' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_mount'

###############################################################################
# BEGIN fix (151 / 244) for 'audit_rules_privileged_commands_umount'
###############################################################################
(>&2 echo "Remediating rule 151/244: 'audit_rules_privileged_commands_umount'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_umount' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_umount'

###############################################################################
# BEGIN fix (152 / 244) for 'audit_rules_privileged_commands_newuidmap'
###############################################################################
(>&2 echo "Remediating rule 152/244: 'audit_rules_privileged_commands_newuidmap'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_newuidmap' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_newuidmap'

###############################################################################
# BEGIN fix (153 / 244) for 'audit_rules_privileged_commands_unix_chkpwd'
###############################################################################
(>&2 echo "Remediating rule 153/244: 'audit_rules_privileged_commands_unix_chkpwd'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_unix_chkpwd' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_unix_chkpwd'

###############################################################################
# BEGIN fix (154 / 244) for 'audit_rules_privileged_commands_ssh_keysign'
###############################################################################
(>&2 echo "Remediating rule 154/244: 'audit_rules_privileged_commands_ssh_keysign'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_ssh_keysign' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_ssh_keysign'

###############################################################################
# BEGIN fix (155 / 244) for 'audit_rules_privileged_commands_sudo'
###############################################################################
(>&2 echo "Remediating rule 155/244: 'audit_rules_privileged_commands_sudo'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_sudo' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_sudo'

###############################################################################
# BEGIN fix (156 / 244) for 'audit_rules_privileged_commands_postdrop'
###############################################################################
(>&2 echo "Remediating rule 156/244: 'audit_rules_privileged_commands_postdrop'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_postdrop' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_postdrop'

###############################################################################
# BEGIN fix (157 / 244) for 'audit_rules_privileged_commands_passwd'
###############################################################################
(>&2 echo "Remediating rule 157/244: 'audit_rules_privileged_commands_passwd'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_passwd' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_passwd'

###############################################################################
# BEGIN fix (158 / 244) for 'audit_rules_privileged_commands_su'
###############################################################################
(>&2 echo "Remediating rule 158/244: 'audit_rules_privileged_commands_su'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_su' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_su'

###############################################################################
# BEGIN fix (159 / 244) for 'audit_rules_privileged_commands_userhelper'
###############################################################################
(>&2 echo "Remediating rule 159/244: 'audit_rules_privileged_commands_userhelper'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_privileged_commands_userhelper' IS MISSING!")

# END fix for 'audit_rules_privileged_commands_userhelper'

###############################################################################
# BEGIN fix (160 / 244) for 'audit_rules_dac_modification_lsetxattr'
###############################################################################
(>&2 echo "Remediating rule 160/244: 'audit_rules_dac_modification_lsetxattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_lsetxattr' IS MISSING!")

# END fix for 'audit_rules_dac_modification_lsetxattr'

###############################################################################
# BEGIN fix (161 / 244) for 'audit_rules_dac_modification_fremovexattr'
###############################################################################
(>&2 echo "Remediating rule 161/244: 'audit_rules_dac_modification_fremovexattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_fremovexattr' IS MISSING!")

# END fix for 'audit_rules_dac_modification_fremovexattr'

###############################################################################
# BEGIN fix (162 / 244) for 'audit_rules_dac_modification_setxattr'
###############################################################################
(>&2 echo "Remediating rule 162/244: 'audit_rules_dac_modification_setxattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_setxattr' IS MISSING!")

# END fix for 'audit_rules_dac_modification_setxattr'

###############################################################################
# BEGIN fix (163 / 244) for 'audit_rules_dac_modification_lchown'
###############################################################################
(>&2 echo "Remediating rule 163/244: 'audit_rules_dac_modification_lchown'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_lchown' IS MISSING!")

# END fix for 'audit_rules_dac_modification_lchown'

###############################################################################
# BEGIN fix (164 / 244) for 'audit_rules_dac_modification_fchownat'
###############################################################################
(>&2 echo "Remediating rule 164/244: 'audit_rules_dac_modification_fchownat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_fchownat' IS MISSING!")

# END fix for 'audit_rules_dac_modification_fchownat'

###############################################################################
# BEGIN fix (165 / 244) for 'audit_rules_dac_modification_fsetxattr'
###############################################################################
(>&2 echo "Remediating rule 165/244: 'audit_rules_dac_modification_fsetxattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_fsetxattr' IS MISSING!")

# END fix for 'audit_rules_dac_modification_fsetxattr'

###############################################################################
# BEGIN fix (166 / 244) for 'audit_rules_dac_modification_fchmodat'
###############################################################################
(>&2 echo "Remediating rule 166/244: 'audit_rules_dac_modification_fchmodat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_fchmodat' IS MISSING!")

# END fix for 'audit_rules_dac_modification_fchmodat'

###############################################################################
# BEGIN fix (167 / 244) for 'audit_rules_dac_modification_chown'
###############################################################################
(>&2 echo "Remediating rule 167/244: 'audit_rules_dac_modification_chown'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_chown' IS MISSING!")

# END fix for 'audit_rules_dac_modification_chown'

###############################################################################
# BEGIN fix (168 / 244) for 'audit_rules_dac_modification_lremovexattr'
###############################################################################
(>&2 echo "Remediating rule 168/244: 'audit_rules_dac_modification_lremovexattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_lremovexattr' IS MISSING!")

# END fix for 'audit_rules_dac_modification_lremovexattr'

###############################################################################
# BEGIN fix (169 / 244) for 'audit_rules_dac_modification_fchown'
###############################################################################
(>&2 echo "Remediating rule 169/244: 'audit_rules_dac_modification_fchown'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_fchown' IS MISSING!")

# END fix for 'audit_rules_dac_modification_fchown'

###############################################################################
# BEGIN fix (170 / 244) for 'audit_rules_dac_modification_fchmod'
###############################################################################
(>&2 echo "Remediating rule 170/244: 'audit_rules_dac_modification_fchmod'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_fchmod' IS MISSING!")

# END fix for 'audit_rules_dac_modification_fchmod'

###############################################################################
# BEGIN fix (171 / 244) for 'audit_rules_dac_modification_chmod'
###############################################################################
(>&2 echo "Remediating rule 171/244: 'audit_rules_dac_modification_chmod'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_chmod' IS MISSING!")

# END fix for 'audit_rules_dac_modification_chmod'

###############################################################################
# BEGIN fix (172 / 244) for 'audit_rules_dac_modification_removexattr'
###############################################################################
(>&2 echo "Remediating rule 172/244: 'audit_rules_dac_modification_removexattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_dac_modification_removexattr' IS MISSING!")

# END fix for 'audit_rules_dac_modification_removexattr'

###############################################################################
# BEGIN fix (173 / 244) for 'audit_rules_execution_setsebool'
###############################################################################
(>&2 echo "Remediating rule 173/244: 'audit_rules_execution_setsebool'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_execution_setsebool' IS MISSING!")

# END fix for 'audit_rules_execution_setsebool'

###############################################################################
# BEGIN fix (174 / 244) for 'audit_rules_execution_setfiles'
###############################################################################
(>&2 echo "Remediating rule 174/244: 'audit_rules_execution_setfiles'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_execution_setfiles' IS MISSING!")

# END fix for 'audit_rules_execution_setfiles'

###############################################################################
# BEGIN fix (175 / 244) for 'audit_rules_execution_chcon'
###############################################################################
(>&2 echo "Remediating rule 175/244: 'audit_rules_execution_chcon'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_execution_chcon' IS MISSING!")

# END fix for 'audit_rules_execution_chcon'

###############################################################################
# BEGIN fix (176 / 244) for 'audit_rules_execution_restorecon'
###############################################################################
(>&2 echo "Remediating rule 176/244: 'audit_rules_execution_restorecon'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_execution_restorecon' IS MISSING!")

# END fix for 'audit_rules_execution_restorecon'

###############################################################################
# BEGIN fix (177 / 244) for 'audit_rules_execution_seunshare'
###############################################################################
(>&2 echo "Remediating rule 177/244: 'audit_rules_execution_seunshare'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_execution_seunshare' IS MISSING!")

# END fix for 'audit_rules_execution_seunshare'

###############################################################################
# BEGIN fix (178 / 244) for 'audit_rules_execution_semanage'
###############################################################################
(>&2 echo "Remediating rule 178/244: 'audit_rules_execution_semanage'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_execution_semanage' IS MISSING!")

# END fix for 'audit_rules_execution_semanage'

###############################################################################
# BEGIN fix (179 / 244) for 'audit_rules_time_adjtimex'
###############################################################################
(>&2 echo "Remediating rule 179/244: 'audit_rules_time_adjtimex'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_time_adjtimex' IS MISSING!")

# END fix for 'audit_rules_time_adjtimex'

###############################################################################
# BEGIN fix (180 / 244) for 'audit_rules_time_stime'
###############################################################################
(>&2 echo "Remediating rule 180/244: 'audit_rules_time_stime'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_time_stime' IS MISSING!")

# END fix for 'audit_rules_time_stime'

###############################################################################
# BEGIN fix (181 / 244) for 'audit_rules_time_clock_settime'
###############################################################################
(>&2 echo "Remediating rule 181/244: 'audit_rules_time_clock_settime'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_time_clock_settime' IS MISSING!")

# END fix for 'audit_rules_time_clock_settime'

###############################################################################
# BEGIN fix (182 / 244) for 'audit_rules_time_watch_localtime'
###############################################################################
(>&2 echo "Remediating rule 182/244: 'audit_rules_time_watch_localtime'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_time_watch_localtime' IS MISSING!")

# END fix for 'audit_rules_time_watch_localtime'

###############################################################################
# BEGIN fix (183 / 244) for 'audit_rules_time_settimeofday'
###############################################################################
(>&2 echo "Remediating rule 183/244: 'audit_rules_time_settimeofday'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_time_settimeofday' IS MISSING!")

# END fix for 'audit_rules_time_settimeofday'

###############################################################################
# BEGIN fix (184 / 244) for 'audit_rules_kernel_module_loading_init'
###############################################################################
(>&2 echo "Remediating rule 184/244: 'audit_rules_kernel_module_loading_init'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_kernel_module_loading_init' IS MISSING!")

# END fix for 'audit_rules_kernel_module_loading_init'

###############################################################################
# BEGIN fix (185 / 244) for 'audit_rules_kernel_module_loading_finit'
###############################################################################
(>&2 echo "Remediating rule 185/244: 'audit_rules_kernel_module_loading_finit'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_kernel_module_loading_finit' IS MISSING!")

# END fix for 'audit_rules_kernel_module_loading_finit'

###############################################################################
# BEGIN fix (186 / 244) for 'audit_rules_kernel_module_loading_delete'
###############################################################################
(>&2 echo "Remediating rule 186/244: 'audit_rules_kernel_module_loading_delete'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_kernel_module_loading_delete' IS MISSING!")

# END fix for 'audit_rules_kernel_module_loading_delete'

###############################################################################
# BEGIN fix (187 / 244) for 'audit_rules_unsuccessful_file_modification_openat_rule_order'
###############################################################################
(>&2 echo "Remediating rule 187/244: 'audit_rules_unsuccessful_file_modification_openat_rule_order'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_openat_rule_order' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_openat_rule_order'

###############################################################################
# BEGIN fix (188 / 244) for 'audit_rules_unsuccessful_file_modification_fchownat'
###############################################################################
(>&2 echo "Remediating rule 188/244: 'audit_rules_unsuccessful_file_modification_fchownat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_fchownat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_fchownat'

###############################################################################
# BEGIN fix (189 / 244) for 'audit_rules_unsuccessful_file_modification_unlinkat'
###############################################################################
(>&2 echo "Remediating rule 189/244: 'audit_rules_unsuccessful_file_modification_unlinkat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_unlinkat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_unlinkat'

###############################################################################
# BEGIN fix (190 / 244) for 'audit_rules_unsuccessful_file_modification_openat_o_creat'
###############################################################################
(>&2 echo "Remediating rule 190/244: 'audit_rules_unsuccessful_file_modification_openat_o_creat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_openat_o_creat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_openat_o_creat'

###############################################################################
# BEGIN fix (191 / 244) for 'audit_rules_unsuccessful_file_modification_removexattr'
###############################################################################
(>&2 echo "Remediating rule 191/244: 'audit_rules_unsuccessful_file_modification_removexattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_removexattr' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_removexattr'

###############################################################################
# BEGIN fix (192 / 244) for 'audit_rules_unsuccessful_file_modification_open_o_trunc_write'
###############################################################################
(>&2 echo "Remediating rule 192/244: 'audit_rules_unsuccessful_file_modification_open_o_trunc_write'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open_o_trunc_write' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open_o_trunc_write'

###############################################################################
# BEGIN fix (193 / 244) for 'audit_rules_unsuccessful_file_modification_fchown'
###############################################################################
(>&2 echo "Remediating rule 193/244: 'audit_rules_unsuccessful_file_modification_fchown'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_fchown' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_fchown'

###############################################################################
# BEGIN fix (194 / 244) for 'audit_rules_unsuccessful_file_modification_chmod'
###############################################################################
(>&2 echo "Remediating rule 194/244: 'audit_rules_unsuccessful_file_modification_chmod'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_chmod' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_chmod'

###############################################################################
# BEGIN fix (195 / 244) for 'audit_rules_unsuccessful_file_modification_open_rule_order'
###############################################################################
(>&2 echo "Remediating rule 195/244: 'audit_rules_unsuccessful_file_modification_open_rule_order'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open_rule_order' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open_rule_order'

###############################################################################
# BEGIN fix (196 / 244) for 'audit_rules_unsuccessful_file_modification_fchmod'
###############################################################################
(>&2 echo "Remediating rule 196/244: 'audit_rules_unsuccessful_file_modification_fchmod'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_fchmod' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_fchmod'

###############################################################################
# BEGIN fix (197 / 244) for 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_trunc_write'
###############################################################################
(>&2 echo "Remediating rule 197/244: 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_trunc_write'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_trunc_write' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_trunc_write'

###############################################################################
# BEGIN fix (198 / 244) for 'audit_rules_unsuccessful_file_modification_creat'
###############################################################################
(>&2 echo "Remediating rule 198/244: 'audit_rules_unsuccessful_file_modification_creat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_creat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_creat'

###############################################################################
# BEGIN fix (199 / 244) for 'audit_rules_unsuccessful_file_modification_ftruncate'
###############################################################################
(>&2 echo "Remediating rule 199/244: 'audit_rules_unsuccessful_file_modification_ftruncate'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_ftruncate' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_ftruncate'

###############################################################################
# BEGIN fix (200 / 244) for 'audit_rules_unsuccessful_file_modification_lremovexattr'
###############################################################################
(>&2 echo "Remediating rule 200/244: 'audit_rules_unsuccessful_file_modification_lremovexattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_lremovexattr' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_lremovexattr'

###############################################################################
# BEGIN fix (201 / 244) for 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_creat'
###############################################################################
(>&2 echo "Remediating rule 201/244: 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_creat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_creat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open_by_handle_at_o_creat'

###############################################################################
# BEGIN fix (202 / 244) for 'audit_rules_unsuccessful_file_modification_rename'
###############################################################################
(>&2 echo "Remediating rule 202/244: 'audit_rules_unsuccessful_file_modification_rename'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_rename' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_rename'

###############################################################################
# BEGIN fix (203 / 244) for 'audit_rules_unsuccessful_file_modification_truncate'
###############################################################################
(>&2 echo "Remediating rule 203/244: 'audit_rules_unsuccessful_file_modification_truncate'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_truncate' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_truncate'

###############################################################################
# BEGIN fix (204 / 244) for 'audit_rules_unsuccessful_file_modification_fremovexattr'
###############################################################################
(>&2 echo "Remediating rule 204/244: 'audit_rules_unsuccessful_file_modification_fremovexattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_fremovexattr' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_fremovexattr'

###############################################################################
# BEGIN fix (205 / 244) for 'audit_rules_unsuccessful_file_modification_lchown'
###############################################################################
(>&2 echo "Remediating rule 205/244: 'audit_rules_unsuccessful_file_modification_lchown'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_lchown' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_lchown'

###############################################################################
# BEGIN fix (206 / 244) for 'audit_rules_unsuccessful_file_modification_renameat'
###############################################################################
(>&2 echo "Remediating rule 206/244: 'audit_rules_unsuccessful_file_modification_renameat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_renameat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_renameat'

###############################################################################
# BEGIN fix (207 / 244) for 'audit_rules_unsuccessful_file_modification_openat_o_trunc_write'
###############################################################################
(>&2 echo "Remediating rule 207/244: 'audit_rules_unsuccessful_file_modification_openat_o_trunc_write'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_openat_o_trunc_write' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_openat_o_trunc_write'

###############################################################################
# BEGIN fix (208 / 244) for 'audit_rules_unsuccessful_file_modification_fsetxattr'
###############################################################################
(>&2 echo "Remediating rule 208/244: 'audit_rules_unsuccessful_file_modification_fsetxattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_fsetxattr' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_fsetxattr'

###############################################################################
# BEGIN fix (209 / 244) for 'audit_rules_unsuccessful_file_modification_setxattr'
###############################################################################
(>&2 echo "Remediating rule 209/244: 'audit_rules_unsuccessful_file_modification_setxattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_setxattr' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_setxattr'

###############################################################################
# BEGIN fix (210 / 244) for 'audit_rules_unsuccessful_file_modification_openat'
###############################################################################
(>&2 echo "Remediating rule 210/244: 'audit_rules_unsuccessful_file_modification_openat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_openat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_openat'

###############################################################################
# BEGIN fix (211 / 244) for 'audit_rules_unsuccessful_file_modification_chown'
###############################################################################
(>&2 echo "Remediating rule 211/244: 'audit_rules_unsuccessful_file_modification_chown'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_chown' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_chown'

###############################################################################
# BEGIN fix (212 / 244) for 'audit_rules_unsuccessful_file_modification_open'
###############################################################################
(>&2 echo "Remediating rule 212/244: 'audit_rules_unsuccessful_file_modification_open'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open'

###############################################################################
# BEGIN fix (213 / 244) for 'audit_rules_unsuccessful_file_modification_fchmodat'
###############################################################################
(>&2 echo "Remediating rule 213/244: 'audit_rules_unsuccessful_file_modification_fchmodat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_fchmodat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_fchmodat'

###############################################################################
# BEGIN fix (214 / 244) for 'audit_rules_unsuccessful_file_modification_lsetxattr'
###############################################################################
(>&2 echo "Remediating rule 214/244: 'audit_rules_unsuccessful_file_modification_lsetxattr'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_lsetxattr' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_lsetxattr'

###############################################################################
# BEGIN fix (215 / 244) for 'audit_rules_unsuccessful_file_modification_open_o_creat'
###############################################################################
(>&2 echo "Remediating rule 215/244: 'audit_rules_unsuccessful_file_modification_open_o_creat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open_o_creat' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open_o_creat'

###############################################################################
# BEGIN fix (216 / 244) for 'audit_rules_unsuccessful_file_modification_unlink'
###############################################################################
(>&2 echo "Remediating rule 216/244: 'audit_rules_unsuccessful_file_modification_unlink'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_unlink' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_unlink'

###############################################################################
# BEGIN fix (217 / 244) for 'audit_rules_unsuccessful_file_modification_open_by_handle_at'
###############################################################################
(>&2 echo "Remediating rule 217/244: 'audit_rules_unsuccessful_file_modification_open_by_handle_at'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open_by_handle_at' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open_by_handle_at'

###############################################################################
# BEGIN fix (218 / 244) for 'audit_rules_unsuccessful_file_modification_open_by_handle_at_rule_order'
###############################################################################
(>&2 echo "Remediating rule 218/244: 'audit_rules_unsuccessful_file_modification_open_by_handle_at_rule_order'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_unsuccessful_file_modification_open_by_handle_at_rule_order' IS MISSING!")

# END fix for 'audit_rules_unsuccessful_file_modification_open_by_handle_at_rule_order'

###############################################################################
# BEGIN fix (219 / 244) for 'audit_rules_login_events_faillock'
###############################################################################
(>&2 echo "Remediating rule 219/244: 'audit_rules_login_events_faillock'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_login_events_faillock' IS MISSING!")

# END fix for 'audit_rules_login_events_faillock'

###############################################################################
# BEGIN fix (220 / 244) for 'audit_rules_login_events_lastlog'
###############################################################################
(>&2 echo "Remediating rule 220/244: 'audit_rules_login_events_lastlog'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_login_events_lastlog' IS MISSING!")

# END fix for 'audit_rules_login_events_lastlog'

###############################################################################
# BEGIN fix (221 / 244) for 'audit_rules_login_events_tallylog'
###############################################################################
(>&2 echo "Remediating rule 221/244: 'audit_rules_login_events_tallylog'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_login_events_tallylog' IS MISSING!")

# END fix for 'audit_rules_login_events_tallylog'

###############################################################################
# BEGIN fix (222 / 244) for 'audit_rules_file_deletion_events_renameat'
###############################################################################
(>&2 echo "Remediating rule 222/244: 'audit_rules_file_deletion_events_renameat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_file_deletion_events_renameat' IS MISSING!")

# END fix for 'audit_rules_file_deletion_events_renameat'

###############################################################################
# BEGIN fix (223 / 244) for 'audit_rules_file_deletion_events_unlinkat'
###############################################################################
(>&2 echo "Remediating rule 223/244: 'audit_rules_file_deletion_events_unlinkat'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_file_deletion_events_unlinkat' IS MISSING!")

# END fix for 'audit_rules_file_deletion_events_unlinkat'

###############################################################################
# BEGIN fix (224 / 244) for 'audit_rules_file_deletion_events_rename'
###############################################################################
(>&2 echo "Remediating rule 224/244: 'audit_rules_file_deletion_events_rename'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_file_deletion_events_rename' IS MISSING!")

# END fix for 'audit_rules_file_deletion_events_rename'

###############################################################################
# BEGIN fix (225 / 244) for 'audit_rules_file_deletion_events_unlink'
###############################################################################
(>&2 echo "Remediating rule 225/244: 'audit_rules_file_deletion_events_unlink'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_file_deletion_events_unlink' IS MISSING!")

# END fix for 'audit_rules_file_deletion_events_unlink'

###############################################################################
# BEGIN fix (226 / 244) for 'audit_rules_file_deletion_events_rmdir'
###############################################################################
(>&2 echo "Remediating rule 226/244: 'audit_rules_file_deletion_events_rmdir'")
(>&2 echo "FIX FOR THIS RULE 'audit_rules_file_deletion_events_rmdir' IS MISSING!")

# END fix for 'audit_rules_file_deletion_events_rmdir'

###############################################################################
# BEGIN fix (227 / 244) for 'package_fapolicyd_installed'
###############################################################################
(>&2 echo "Remediating rule 227/244: 'package_fapolicyd_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_fapolicyd_installed' IS MISSING!")

# END fix for 'package_fapolicyd_installed'

###############################################################################
# BEGIN fix (228 / 244) for 'service_fapolicyd_enabled'
###############################################################################
(>&2 echo "Remediating rule 228/244: 'service_fapolicyd_enabled'")
(>&2 echo "FIX FOR THIS RULE 'service_fapolicyd_enabled' IS MISSING!")

# END fix for 'service_fapolicyd_enabled'

###############################################################################
# BEGIN fix (229 / 244) for 'sssd_run_as_sssd_user'
###############################################################################
(>&2 echo "Remediating rule 229/244: 'sssd_run_as_sssd_user'")
(>&2 echo "FIX FOR THIS RULE 'sssd_run_as_sssd_user' IS MISSING!")

# END fix for 'sssd_run_as_sssd_user'

###############################################################################
# BEGIN fix (230 / 244) for 'service_rngd_enabled'
###############################################################################
(>&2 echo "Remediating rule 230/244: 'service_rngd_enabled'")
(>&2 echo "FIX FOR THIS RULE 'service_rngd_enabled' IS MISSING!")

# END fix for 'service_rngd_enabled'

###############################################################################
# BEGIN fix (231 / 244) for 'service_chronyd_or_ntpd_enabled'
###############################################################################
(>&2 echo "Remediating rule 231/244: 'service_chronyd_or_ntpd_enabled'")
(>&2 echo "FIX FOR THIS RULE 'service_chronyd_or_ntpd_enabled' IS MISSING!")

# END fix for 'service_chronyd_or_ntpd_enabled'

###############################################################################
# BEGIN fix (232 / 244) for 'chronyd_no_chronyc_network'
###############################################################################
(>&2 echo "Remediating rule 232/244: 'chronyd_no_chronyc_network'")
(>&2 echo "FIX FOR THIS RULE 'chronyd_no_chronyc_network' IS MISSING!")

# END fix for 'chronyd_no_chronyc_network'

###############################################################################
# BEGIN fix (233 / 244) for 'chronyd_or_ntpd_specify_multiple_servers'
###############################################################################
(>&2 echo "Remediating rule 233/244: 'chronyd_or_ntpd_specify_multiple_servers'")
(>&2 echo "FIX FOR THIS RULE 'chronyd_or_ntpd_specify_multiple_servers' IS MISSING!")

# END fix for 'chronyd_or_ntpd_specify_multiple_servers'

###############################################################################
# BEGIN fix (234 / 244) for 'chronyd_or_ntpd_set_maxpoll'
###############################################################################
(>&2 echo "Remediating rule 234/244: 'chronyd_or_ntpd_set_maxpoll'")
(>&2 echo "FIX FOR THIS RULE 'chronyd_or_ntpd_set_maxpoll' IS MISSING!")

# END fix for 'chronyd_or_ntpd_set_maxpoll'

###############################################################################
# BEGIN fix (235 / 244) for 'chronyd_or_ntpd_specify_remote_server'
###############################################################################
(>&2 echo "Remediating rule 235/244: 'chronyd_or_ntpd_specify_remote_server'")
(>&2 echo "FIX FOR THIS RULE 'chronyd_or_ntpd_specify_remote_server' IS MISSING!")

# END fix for 'chronyd_or_ntpd_specify_remote_server'

###############################################################################
# BEGIN fix (236 / 244) for 'chronyd_client_only'
###############################################################################
(>&2 echo "Remediating rule 236/244: 'chronyd_client_only'")
(>&2 echo "FIX FOR THIS RULE 'chronyd_client_only' IS MISSING!")

# END fix for 'chronyd_client_only'

###############################################################################
# BEGIN fix (237 / 244) for 'sshd_set_keepalive'
###############################################################################
(>&2 echo "Remediating rule 237/244: 'sshd_set_keepalive'")
(>&2 echo "FIX FOR THIS RULE 'sshd_set_keepalive' IS MISSING!")

# END fix for 'sshd_set_keepalive'

###############################################################################
# BEGIN fix (238 / 244) for 'sshd_disable_rhosts'
###############################################################################
(>&2 echo "Remediating rule 238/244: 'sshd_disable_rhosts'")
if [ -e "/etc/ssh/sshd_config" ] ; then
    LC_ALL=C sed -i "/^\s*IgnoreRhosts\s\+/Id" "/etc/ssh/sshd_config"
else
    touch "/etc/ssh/sshd_config"
fi
cp "/etc/ssh/sshd_config" "/etc/ssh/sshd_config.bak"
# Insert before the line matching the regex '^Match'.
line_number="$(LC_ALL=C grep -n "^Match" "/etc/ssh/sshd_config.bak" | LC_ALL=C sed 's/:.*//g')"
if [ -z "$line_number" ]; then
    # There was no match of '^Match', insert at
    # the end of the file.
    printf '%s\n' "IgnoreRhosts yes" >> "/etc/ssh/sshd_config"
else
    head -n "$(( line_number - 1 ))" "/etc/ssh/sshd_config.bak" > "/etc/ssh/sshd_config"
    printf '%s\n' "IgnoreRhosts yes" >> "/etc/ssh/sshd_config"
    tail -n "+$(( line_number ))" "/etc/ssh/sshd_config.bak" >> "/etc/ssh/sshd_config"
fi
# Clean up after ourselves.
rm "/etc/ssh/sshd_config.bak"

# END fix for 'sshd_disable_rhosts'

###############################################################################
# BEGIN fix (239 / 244) for 'sshd_limit_user_access'
###############################################################################
(>&2 echo "Remediating rule 239/244: 'sshd_limit_user_access'")
(>&2 echo "FIX FOR THIS RULE 'sshd_limit_user_access' IS MISSING!")

# END fix for 'sshd_limit_user_access'

###############################################################################
# BEGIN fix (240 / 244) for 'sshd_set_idle_timeout'
###############################################################################
(>&2 echo "Remediating rule 240/244: 'sshd_set_idle_timeout'")
(>&2 echo "FIX FOR THIS RULE 'sshd_set_idle_timeout' IS MISSING!")

# END fix for 'sshd_set_idle_timeout'

###############################################################################
# BEGIN fix (241 / 244) for 'package_usbguard_installed'
###############################################################################
(>&2 echo "Remediating rule 241/244: 'package_usbguard_installed'")
(>&2 echo "FIX FOR THIS RULE 'package_usbguard_installed' IS MISSING!")

# END fix for 'package_usbguard_installed'

###############################################################################
# BEGIN fix (242 / 244) for 'service_usbguard_enabled'
###############################################################################
(>&2 echo "Remediating rule 242/244: 'service_usbguard_enabled'")
(>&2 echo "FIX FOR THIS RULE 'service_usbguard_enabled' IS MISSING!")

# END fix for 'service_usbguard_enabled'

###############################################################################
# BEGIN fix (243 / 244) for 'usbguard_allow_hid_and_hub'
###############################################################################
(>&2 echo "Remediating rule 243/244: 'usbguard_allow_hid_and_hub'")
(>&2 echo "FIX FOR THIS RULE 'usbguard_allow_hid_and_hub' IS MISSING!")

# END fix for 'usbguard_allow_hid_and_hub'

###############################################################################
# BEGIN fix (244 / 244) for 'configure_usbguard_auditbackend'
###############################################################################
(>&2 echo "Remediating rule 244/244: 'configure_usbguard_auditbackend'")
if [ -e "/etc/usbguard/usbguard-daemon.conf" ] ; then
    LC_ALL=C sed -i "/^\s*AuditBackend=/d" "/etc/usbguard/usbguard-daemon.conf"
else
    touch "/etc/usbguard/usbguard-daemon.conf"
fi
cp "/etc/usbguard/usbguard-daemon.conf" "/etc/usbguard/usbguard-daemon.conf.bak"
# Insert at the end of the file
printf '%s\n' "AuditBackend=LinuxAudit" >> "/etc/usbguard/usbguard-daemon.conf"
# Clean up after ourselves.
rm "/etc/usbguard/usbguard-daemon.conf.bak"

# END fix for 'configure_usbguard_auditbackend'

